@@ -27,10 +27,11 @@ class NumericTypeItem(DataItem):
     Numeric data item
     """
     type = None
-    def __init__(self, label, default=None,
-                 min=None, max=None, nonzero=None, help=''):
+    def __init__(self, label, default=None, min=None, max=None,
+                 nonzero=None, unit='', help=''):
         DataItem.__init__(self, label, default=default, help=help)
         self.set_prop("data", min=min, max=max, nonzero=nonzero)
+        self.set_prop("display", unit=unit)
         
     def get_auto_help(self, instance):
         """Override DataItem method"""
@@ -38,6 +39,7 @@ class NumericTypeItem(DataItem):
         _min = self.get_prop_value("data", instance, "min")
         _max = self.get_prop_value("data", instance, "max")
         nonzero = self.get_prop_value("data", instance, "nonzero")
+        unit = self.get_prop_value("display", instance, "unit")
         if _min is not None and _max is not None:
             auto_help += _(" between ")+str(_min)+ _(" and ")+str(_max)
         elif _min is not None:
@@ -46,7 +48,19 @@ class NumericTypeItem(DataItem):
             auto_help += _(" lower than ")+str(_max)
         if nonzero:
             auto_help += ", "+_("non zero")
+        if unit:
+            auto_help += (", %s %s" % (_("unit:"), unit))
         return auto_help
+        
+    def format_string(self, instance, value, fmt, func):
+        """Override DataItem method"""
+        text = fmt % (func(value), )
+        # We add directly the unit to 'text' (instead of adding it 
+        # to 'fmt') to avoid string formatting error if '%' is in unit
+        unit = self.get_prop_value("display", instance, "unit", '')
+        if unit:
+            text += ' '+unit
+        return text
 
     def check_value(self, value):
         """Override DataItem method"""
@@ -84,6 +98,7 @@ class FloatItem(NumericTypeItem):
         * min [float]: minimum value (optional)
         * max [float]: maximum value (optional)
         * nonzero [bool]: if True, zero is not a valid value (optional)
+        * unit [string]: physical unit (optional)
         * help [string]: text shown in tooltip (optional)
     """
     type = float
@@ -97,16 +112,20 @@ class IntItem(NumericTypeItem):
         * min [int]: minimum value (optional)
         * max [int]: maximum value (optional)
         * nonzero [bool]: if True, zero is not a valid value (optional)
-        * even [bool]: if True, even values are valid, if False, odd values are valid
-                 if None (default), ignored (optional)
+        * unit [string]: physical unit (optional)
+        * even [bool]: if True, even values are valid, if False,
+          odd values are valid if None (default), ignored (optional)
+        * slider [bool]: if True, shows a slider widget right after the line 
+          edit widget (default is False)
         * help [string]: text shown in tooltip (optional)
     """
     type = int
-    def __init__(self, label, default=None,
-                 min=None, max=None, nonzero=None, even=None, help=''):
+    def __init__(self, label, default=None, min=None, max=None,
+                 nonzero=None, unit='', even=None, slider=False, help=''):
         super(IntItem, self).__init__(label, default=default, min=min, max=max,
-                                      nonzero=nonzero, help=help)
+                                      nonzero=nonzero, unit=unit, help=help)
         self.set_prop("data", even=even)
+        self.set_prop("display", slider=slider)
         
     def get_auto_help(self, instance):
         """Override DataItem method"""
@@ -359,6 +378,17 @@ class ChoiceItem(DataItem):
 #        if callable(_choices_data):
 #            return _choices_data(self, item)
 #        return _choices_data
+
+    def get_string_value(self, instance):
+        """Override DataItem method"""
+        value = self.get_value(instance)
+        choices = self.get_prop_value("data", instance, "choices")
+        #print "ShowChoiceWidget:", choices, value
+        for choice in choices:
+            if choice[0] == value:
+                return unicode(choice[1])
+        else:
+            return DataItem.get_string_value(self, instance)
         
         
 class MultipleChoiceItem(ChoiceItem):
@@ -458,6 +488,11 @@ class FloatArrayItem(DataItem):
         DataItem.__init__(self, label, default=default, help=help)
         self.set_prop("display", format=format, transpose=transpose,
                       minmax=minmax)
+        
+    def format_string(self, instance, value, fmt, func):
+        """Override DataItem method"""
+        v = func(value)
+        return u"~= %g [%g .. %g]" % (v.mean(), v.min(), v.max())
 
 
 class ButtonItem(DataItem):
@@ -500,7 +535,7 @@ class DictItem(ButtonItem):
     """
     def __init__(self, label, default=None, help=''):
         def dictedit(instance, item, value, parent):
-            from guidata.editors.dicteditor import DictEditor
+            from spyderlib.widgets.dicteditor import DictEditor
             editor = DictEditor(parent)
             value_was_none = value is None
             if value_was_none:
